@@ -18,12 +18,11 @@ m = IMP.Model()
 # Create a new IMP.atom.Hierarchy from the contents of the pdb file
 h = IMP.atom.read_pdb(IMP.rmf.get_example_path("simple.pdb"), m)
 
-# find the name for a temporary file to use to for writing the hdf5 file
-tfn = IMP.create_temporary_file_name("link", ".rmf")
+tfn = "link.rmf"
 
 print("File name is", tfn)
 
-# open the temporary file, clearing any existing contents
+# open the file, clearing any existing contents
 rh = RMF.create_rmf_file(tfn)
 
 # add the hierarchy to the file
@@ -44,4 +43,4 @@ IMP.rmf.link_hierarchies(rh, [h])
 # load the same coordinates in, ok, that is not very exciting
 IMP.rmf.load_frame(rh, RMF.FrameID(0))
 
-print("Try running hdf5_display or hdf5_show on", tfn)
+print("Try running rmf_display or rmf_show on", tfn)
